##########################################################################
#                                                                        #
#           copyright (c) 2003 ITB, Humboldt-University Berlin           #
#           written by: Raphael Ritz, r.ritz@biologie.hu-berlin.de       #
#                                                                        #
##########################################################################

"""Article reference main class"""

from Products.CMFCore import CMFCorePermissions

from Products.Archetypes.public import Schema
from Products.Archetypes.public import StringField, StringWidget
from Products.Archetypes.public import registerType

from Products.CMFBibliographyAT.marshall import BibtexMarshaller
from Products.CMFBibliographyAT.content.base import BaseEntry
from Products.CMFBibliographyAT.content.schemata \
    import HeaderSchema, AuthorSchema, CoreSchema, TrailingSchema
from Products.CMFBibliographyAT.content.fields \
    import journalField, volumeField, numberField, pagesField


SourceSchema = Schema((
    journalField,
    volumeField,
    numberField,
    pagesField,
    StringField('pmid',
        widget=StringWidget(label="PMID",
            label_msgid="label_source_pmid",
            description="The reference's number in the PubMed database.",
            description_msgid="help_source_pmid",
            i18n_domain="plone",),
            ),
    ))

ArticleSchema = HeaderSchema + AuthorSchema + CoreSchema +  \
                SourceSchema + TrailingSchema


class ArticleReference(BaseEntry):
    """ content type to make reference to a (scientific) article.
    """
    archetype_name = "Article Reference"
    source_fields = ('journal', 'volume', 'number', 'pages', 'pmid')

    schema = ArticleSchema

    def PMID(self):
        """ returns the pmid if set
        """
        value = self.getPmid()
        if value:
            return value
        else:
            return None

    def getPubMedLink(self, defaultURL=None):
        """ a link to PubMed
            if pmid is set or the default otherwise
        """
        if self.getPmid():
            url = "http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve"
            return url + "&db=PubMed&list_uids=%s" % self.getPmid()
        else: return defaultURL


    def Source(self):
        """ the default article source format
        """
        try:
            return self.ArticleSource()
        except AttributeError:
            return self.portal_type


registerType(ArticleReference)
