##########################################################################
#                                                                        #
#           copyright (c) 2003 ITB, Humboldt-University Berlin           #
#           written by: Raphael Ritz, r.ritz@biologie.hu-berlin.de       #
#                                                                        #
##########################################################################

"""Inbook reference main class"""

from Products.CMFCore import CMFCorePermissions

from Products.Archetypes.public import registerType
from Products.Archetypes.public import Schema
from Products.Archetypes.public import StringField, BooleanField
from Products.Archetypes.public import StringWidget, BooleanWidget

from Products.CMFBibliographyAT.content.base import BaseEntry
from Products.CMFBibliographyAT.content.schemata \
    import HeaderSchema, AuthorSchema, CoreSchema, TrailingSchema
from Products.CMFBibliographyAT.content.fields \
    import booktitleField, editorField, publisherField, addressField, \
           editionField, seriesField, chapterField, pagesField


SourceSchema = Schema((
    booktitleField,
    editorField,
    publisherField,
    addressField,
    editionField,
    seriesField,
    chapterField,
    pagesField,
    ))

InbookSchema = HeaderSchema + AuthorSchema + CoreSchema +  \
               SourceSchema + TrailingSchema


class InbookReference(BaseEntry):
    """ content type to make reference to a part/chapter within a book.
    """
    archetype_name = "Inbook Reference"
    source_fields = ('booktitle', 'editor', 'publisher', 'address', 'edition', 'series', 'chapter', 'pages')

    schema = InbookSchema

    def Source(self):
        """ the default 'in book' source format
        """
        try:
            return self.InbookSource()
        except AttributeError:
            return self.portal_type


registerType(InbookReference)
