from Products.Archetypes.public import BaseSchema, Schema
from Products.Archetypes.public import StringField, TextField, LinesField, ReferenceField
from Products.Archetypes.public import SelectionWidget, ReferenceWidget, TextAreaWidget
from Products.Archetypes.public import RichWidget, IdWidget, StringWidget
from Products.Archetypes.public import DisplayList
from Products.Archetypes.Widget import TypesWidget

from Products.CMFBibliographyAT.marshall import BibtexMarshaller

# custom widget for TTW author input handling (AT1.3 compliant)
class AuthorsWidget(TypesWidget):
    _properties = TypesWidget._properties.copy()
    _properties.update({
        'macro' : "authors_widget",
        })
try:
    from Products.Archetypes.Registry import registerWidget
    registerWidget(AuthorsWidget)
except ImportError:
    pass

HeaderSchema = BaseSchema.copy()

tmp_title = HeaderSchema['title']
del HeaderSchema['title']

AuthorSchema = Schema((
    ReferenceField('member_publication_authors',
        relationship='authorOf',
        vocabulary='getMembers',
        mutator='setMemberPublicationAuthors',
        languageIndependent=1,
        multiValued=1,
        widget=ReferenceWidget(label='Authors',
            description='',
            condition='python:object.showMemberAuthors()',
            i18n_domain='plone'
            ),
        ),
    LinesField('publication_authors',
        searchable=1,
        required=0,
        multiValued=1,
        languageIndependent=1,
        default=[],
        widget=AuthorsWidget(label="Authors",
            label_msgid="label_name",
            description="Authors names.",
            description_msgid="help_name",
            i18n_domain="plone",
            ),
        accessor="Authors",
        edit_accessor="getAuthorList",
        mutator="setAuthors",
##        write_permission=CMFCorePermissions.ModifyPortalContent
        ),
    ))

CoreSchema = Schema((
    tmp_title,
    StringField('publication_year',
        searchable=1,
        required=1,
        languageIndependent=1,
        widget=StringWidget(label="Publication Year",
            label_msgid="label_publication_year",
            description_msgid="help_publication_year",
            description="Year of publication.",
            i18n_domain="plone",
            ),
        ),
    StringField('publication_url',
        required=0,
        searchable=0,
##        validators=('isURL',),    # re-enable if it doesn't fail
                                    # for empty values any more
        widget=StringWidget(label_msgid="label_bibref_url",
            label="URL",
            description_msgid="help_bibref_url",
            description="The URL to get to the referenced resource.",
            i18n_domain="plone",
            ),
        ),
    TextField('abstract',
        searchable=1,
        required=0,
        allowable_content_types=('text/plain',
                                 'text/structured',
                                 'text/html',),
##        default_output_type="text/plain",
        accessor="getAbstract",
        edit_accessor="getAbstract",
        mutator="setAbstract",
        widget=TextAreaWidget(label="Abstract",
            label_msgid="label_bibref_abstract",
            description_msgid="help_bibref_abstract",
            description="An abstract of the referenced publication.",
            i18n_domain="plone",
            ),
        ),
##    StringField('dummy'),
    ))

TrailingSchema = Schema((
    StringField('publication_month',
        searchable=1,
        required=0,
        languageIndependent=1,
        widget=StringWidget(label="Publication Month",
            label_msgid="label_publication_month",
            description_msgid="help_publication_month",
            description="Month of publication.",
            i18n_domain="plone",
            ),
        ),
    TextField('note',
        searchable=1,
        required=0,
        widget=TextAreaWidget(label="Note",
            label_msgid="label_bibref_note",
            description_msgid="help_bibref_note",
            description="Any additionnal note.",
            i18n_domain="plone",
            ),
        ),
    ), marshall = BibtexMarshaller())

