## Controller Python Script "bibliography_import"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=up_text=None,file=None,format='bib'
##title=
##

from Products.CMFBibliographyAT.BibliographyTool import ImportParseError

start_time = context.ZopeTime().timeTime()
if up_text:
    source = up_text
else:
    if file is None:
        filename=None
    else:
        filename=getattr(file, 'filename', None)
    if not filename:
        state.setError('file', 'You must import a file.')
        return state.set(status='failure',
                         portal_status_message='Please correct the indicated errors.')
    # make sure the path entered in the field matches a file
    try:
        source = file.filename.read()
    except:
        source = file.read()
    if not source or not same_type(source,''):
        state.setError('file', "Could not read the file '%s'." %file.filename)
        return state.set(status='failure',
                         portal_status_message='Please correct the indicated errors.')

# skip DOS line breaks
source = source.replace('\r','')

# get parsed entries from the Bibliography Tool
bibtool = context.portal_bibliography
try:
    if file:
        entries = bibtool.getEntries(source, format, file.filename)
    else:
        entries = bibtool.getEntries(source, format)
except ImportParseError:
    state.setError('format', 'Select an appropriate format for your file.')
    return state.set(status='failure',
                     portal_status_message="%s Parser's 'checkFormat' and guessing the format from the file name '%s' failed." % (format, file.filename))

# debug message if entries is not a python list
if not entries or not same_type(entries, []):
    state.setError('file', "Here is what came as entries: %s." % entries)
    return state.set(status='failure',
                     portal_status_message="There must be something wrong with the parser")

# start building the report
mtool  = context.portal_membership
member = mtool.getAuthenticatedMember()
member_id = member.getId()
fullname = member.getProperty('fullname', None)
if not fullname:
    fullname = 'unknown fullname'
import_date = context.ZopeTime()
if file:
    tmp_report = '[%s] Imported by %s (%s) from file %s:\n\n' \
                 %(import_date, member_id, fullname, file.filename)
else:
    tmp_report = '[%s] Imported by %s (%s):\n\n' \
                 %(import_date, member_id, fullname)

# process import for each entry
processedEntries = 0
importErrors = 0
for entry in entries:
    if entry.get('title'):
        upload = context.processSingleImport(entry)
        if upload[1] == 'ok':
            processedEntries += 1
        else:
            importErrors += 1
        tmp_report = tmp_report + upload[0]

# finish building and write the report
old_report = context.getProperty('import_report', '')
report = tmp_report \
       + '='*30 + '\n' \
       + old_report
context.manage_changeProperties(import_report=report)

# set the portal status message up
msg = "Processed Entries: %i. Errors: %i. Import Processed in %f seconds. See Import Report below." \
      %(processedEntries, importErrors, context.ZopeTime().timeTime()-start_time)
state.set(portal_status_message=msg)

# allow import report display in import form
state.set(processed_import=1)

if state.getErrors():
    return state.set(status='failure',
                     portal_status_message='Please correct the indicated errors.')
else:
    return state
